
__version__ = "2021.06.09.2"
# from . import tools, data, my_random
from .tools import *
from . import my_random, os

'''
For third-party packages, import manually by something like:
import tools.pytorch
import tools.pytorch as tpytorch
import tools.pytorch as tpt

'''
